This function reads two dataframes the one with chromosome sizes, and one df
with data of marks (sites) both have to have the column chrName and if
several species, OTU. The functions returns TRUE if names of
chromosomes in dataframe of marks are included in dataframe of chr. size.
checkNameChrDfMarks(dfChrSize, dfMarks)dataframe, with columns: OTU (optional), chrName, for chr. with cen.: shortArmSize, longArmSize, for holoc.: chrSize
dataframe, of marks (sites): OTU (opt / mandat. if in dfChrSize), chrName markName markSize, for chr. with cen.: markArm (p,q) markDistCen, for holoc: markPos
logical